.. SPDX-FileCopyrightText: 2023 GSI Helmholtzzentrum fuer Schwerionenforschung GmbH, Darmstadt, Germany
..
.. SPDX-License-Identifier: LGPL-3.0-only

ti.ina238 module
================

.. automodule:: ti.ina238
   :members:
   :private-members:
   :undoc-members:
   :special-members: __init__
